##  Authentication Options for ServiceNow
When adding a ServiceNow configuration, you need to select an authentication method and specify the required details. If needed, you can change the authentication method for your existing configurations.
The ServiceNow integration supports the following authentication methods:
  * Basic authentication: This method requires the username and password of the integration user that you created in ServiceNow. This user is a specific account created for the purpose of the integration. For instructions on how to create an integration user, see [Create an Integration user](https://help.sap.com/docs/leanix/ea/setup-in-servicenow?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cc0f97a441014ab90fe667ea172ba__create_an_integration_user).
  * Certificate-based authentication: This method uses a private key and certificate to establish an SSL connection with your ServiceNow instance. During the SSL handshake, the certificate and private key are used to identify the client and the corresponding ServiceNow user for authorization. This method ensures a secure connection between the client and ServiceNow. To learn how to set up this authentication method, refer to the [ServiceNow documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdocs.servicenow.com%2Fbundle%2Fvancouver-platform-security%2Fpage%2Fintegrate%2Fauthentication%2Fconcept%2Fcertificate-based-authentication.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://docs.servicenow.com/bundle/vancouver-platform-security/page/integrate/authentication/concept/certificate-based-authentication.html").
  * OAuth authentication: This method uses tokens instead of credentials to grant access. Provide the following details:
    * Username and password: Enter the username and password of the integration user that you created in ServiceNow. For instructions, see [Create an Integration user](https://help.sap.com/docs/leanix/ea/setup-in-servicenow?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cc0f97a441014ab90fe667ea172ba__create_an_integration_user).
    * Client ID and secret: Enter the client ID and client secret that you obtained in ServiceNow when enabling OAuth 2.0 for authentication. For details, see [Optional: Enable OAuth 2.0 for Authentication](https://help.sap.com/docs/leanix/ea/setup-in-servicenow?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cc0f97a441014ab90fe667ea172ba__enable_oauth_2.0_for_authentication).
